==> apache-wicket-8.17.0.zip: apache-wicket-8.17.0/wicket-guice/src/test/java/org/apache/wicket/guice/GuiceFieldValueFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.guice;

import java.lang.reflect.Field;

import org.junit.Test;

/**
 * Tests for GuiceFieldValueFactory
 */
public class GuiceFieldValueFactoryTest extends AbstractInjectorTest
{
	/**
	 * https://issues.apache.org/jira/browse/WICKET-6020
	 */
	@Test
	public void getFieldValueShouldReturnNullEvenWhenUsingTheCache() throws Exception
	{
		GuiceFieldValueFactory factory = new GuiceFieldValueFactory(false);
		TestComponent owner = new TestComponent("id");
		Field field = TestComponent.class.getDeclaredField("injectedOptionalField");

		// no cache
		Object value = factory.getFieldValue(field, owner);
		assertNull(value);

		// from cache
		Object value2 = factory.getFieldValue(field, owner);
		assertNull(value2);
	}

	@Override
	protected TestNoComponentInterface newTestNoComponent()
	{
		return new TestNoComponent();
	}

	@Override
	protected TestComponentInterface newTestComponent(String id)
	{
		return new TestComponent(id);
	}
}

==> apache-wicket-10.7.0.zip: apache-wicket-10.7.0/wicket-guice/src/test/java/org/apache/wicket/guice/GuiceFieldValueFactoryTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.guice;

import static org.junit.jupiter.api.Assertions.assertNull;

import java.lang.reflect.Field;

import org.junit.jupiter.api.Test;

/**
 * Tests for GuiceFieldValueFactory
 */
public class GuiceFieldValueFactoryTest extends AbstractInjectorTest
{
	/**
	 * https://issues.apache.org/jira/browse/WICKET-6020
	 */
	@Test
	public void getFieldValueShouldReturnNullEvenWhenUsingTheCache() throws Exception
	{
		GuiceFieldValueFactory factory = new GuiceFieldValueFactory(false);
		TestComponent owner = new TestComponent("id");
		Field field = TestComponent.class.getDeclaredField("injectedOptionalField");

		// no cache
		Object value = factory.getFieldValue(field, owner);
		assertNull(value);

		// from cache
		Object value2 = factory.getFieldValue(field, owner);
		assertNull(value2);
	}

	@Override
	protected TestNoComponentInterface newTestNoComponent()
	{
		return new TestNoComponent();
	}

	@Override
	protected TestComponentInterface newTestComponent(String id)
	{
		return new TestComponent(id);
	}
}
